#!/bin/bash
#/////////////////////////////////////////////////////////////////////////
#//
#// (c) University of Southampton IT Innovation Centre, 2018
#//
#// Copyright in this software belongs to University of Southampton
#// IT Innovation Centre of Gamma House, Enterprise Road,
#// Chilworth Science Park, Southampton, SO16 7NS, UK.
#//
#// This software may not be used, sold, licensed, transferred, copied
#// or reproduced in whole or in part in any manner or form or in or
#// on any media by any person other than in accordance with the terms
#// of the Licence Agreement supplied with the software, or otherwise
#// without the prior written consent of the copyright owners.
#//
#// This software is distributed WITHOUT ANY WARRANTY, without even the
#// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#// PURPOSE, except where stated in the Licence Agreement supplied with
#// the software.
#//
#//      Created By :            Simon Crowle
#//      Created Date :          18/04/2018
#//      Created for Project :   FLAME
#//
#/////////////////////////////////////////////////////////////////////////

# Prerequisites
sudo apt-get update
sudo apt-get install -y wget git

# Environment variables for this process
GOROOT=/usr/local/go
PATH=$PATH:$GOROOT/bin
CGO_ENABLED=0
env MINIO_UPDATE=off

# Install GO
# -----------------------------------------------------------------------
cd /tmp
wget https://dl.google.com/go/go1.10.1.linux-amd64.tar.gz
sudo tar -C /usr/local -xzf go1.10.1.linux-amd64.tar.gz

# Install MINIO
# -----------------------------------------------------------------------
sudo mkdir -p /usr/local/go/src/github.com/minio
cd /usr/local/go/src/github.com/minio
git clone https://github.com/minio/minio

cd minio
go install -v -ldflags "$(go run buildscripts/gen-ldflags.go)"

# check minio configuration available
MINIO_CONF_SOURCE=$REPO_ROOT"/src/test/clmctest/services/minio/minio.conf"
if [ ! -f "$MINIO_CONF_SOURCE" ]; then
    echo "Error: MINIO conf file does not exist on in the repo. "$MINIO_CONF_SOURCE
    exit 1
fi

# configure minio & check
sudo mkdir -p /etc/minio
MINIO_CONF_TARGET="/etc/minio/config.json"
sudo cp -rf $MINIO_CONF_SOURCE $MINIO_CONF_TARGET

if [ ! -f "$MINIO_CONF_TARGET" ]; then
    echo "Error: MINIO conf copy failed to target machine. "$MINIO_CONF_TARGET
    exit 1
fi

# create local data directory
data_dir=/var/lib/minio/minio_data
mkdir -p ${data_dir}

# Install minio as systemctl service
# -----------------------------------------------------------------------
start_script_file="/usr/local/go/bin/minio.service.sh"
echo "#!/bin/bash" > $start_script_file
echo "${GOROOT}/bin/minio server --config-dir /etc/minio  ${data_dir} &" >> $start_script_file

chmod 755 $start_script_file

file="/lib/systemd/system/minio.service"
echo "[Unit]" > $file
echo "Description=minio" >> $file
echo "After=network.target" >> $file
echo "" >> $file
echo "[Service]" >> $file
echo "Environment=GOROOT=${GOROOT}" >> $file
echo "Environment=PATH=${PATH}" >> $file
echo "Environment=CGO_ENABLED=${CGO_ENABLED}" >> $file
echo "Environment=MINIO_UPDATE=${MINIO_UPDATE}" >> $file
echo "Type=forking" >> $file
echo "ExecStart=${start_script_file}" >> $file
echo "" >> $file
echo "[Install]" >> $file
echo "WantedBy=multi-user.target" >> $file

systemctl daemon-reload
systemctl enable minio.service
systemctl start minio.service




